@@ -41,7 +41,6 @@
 #include "ShellCommand.h"
 #include "KonsoleSettings.h"
 #include "ViewManager.h"
-#include "SessionController.h"
 #include "WindowSystemInfo.h"
 #include "ViewContainer.h"
 #include "TerminalDisplay.h"
@@ -136,13 +135,13 @@ void Application::populateCommandLineParser(QCommandLineParser *parser)
     auto titleOption = QCommandLineOption({ QStringLiteral("T") },
                                           QStringLiteral("Debian policy compatibility, not used"),
                                           QStringLiteral("value"));
-    titleOption.setHidden(true);
+    titleOption.setFlags(QCommandLineOption::HiddenFromHelp);
     parser->addOption(titleOption);
 }
 
 QStringList Application::getCustomCommand(QStringList &args)
 {
-    int i = args.indexOf(QStringLiteral("-e"));
+    int i = args.indexOf(QLatin1String("-e"));
     QStringList customCommand;
     if ((0 < i) && (i < (args.size() - 1))) {
         // -e was specified with at least one extra argument
@@ -311,8 +310,8 @@ bool Application::processTabsFromFileArgs(MainWindow *window)
             lineTokens[key] = value;
         }
         // should contain at least one of 'command' and 'profile'
-        if (lineTokens.contains(QStringLiteral("command"))
-            || lineTokens.contains(QStringLiteral("profile"))) {
+        if (lineTokens.contains(QLatin1String("command"))
+            || lineTokens.contains(QLatin1String("profile"))) {
             createTabFromArgs(window, lineTokens);
             sessions++;
         } else {
