@@ -56,7 +56,7 @@ class KONSOLEPRIVATE_EXPORT ColorSchemeEditor : public QDialog
 
 public:
     /** Constructs a new color scheme editor with the specified parent. */
-    explicit ColorSchemeEditor(QWidget *parent = 0);
+    explicit ColorSchemeEditor(QWidget *parent = nullptr);
     ~ColorSchemeEditor() Q_DECL_OVERRIDE;
 
     /** Initializes the dialog with the properties of the specified color scheme. */
@@ -77,6 +77,7 @@ public Q_SLOTS:
 
 private Q_SLOTS:
     void setTransparencyPercentLabel(int percent);
+    void setBlur(bool blur);
     void setRandomizedBackgroundColor(bool randomized);
     void editColorItem(QTableWidgetItem *item);
     void wallpaperPathChanged(const QString &path);
@@ -85,6 +86,8 @@ private Q_SLOTS:
     void saveColorScheme();
 
 private:
+    Q_DISABLE_COPY(ColorSchemeEditor)
+
     void setupColorTable(const ColorScheme *table);
 
     bool _isNewScheme;
