@@ -41,7 +41,8 @@ protected:
     void mousePressEvent(QMouseEvent *event) override;
     void mouseMoveEvent(QMouseEvent*event) override;
     void mouseReleaseEvent(QMouseEvent *event) override;
-    bool droppedContainerIsNotThis(const QPoint& currentPos) const;
+    void dragEnterEvent(QDragEnterEvent *event) override;
+    void dragMoveEvent(QDragMoveEvent * event) override;
 
 private:
     DragType dragType;
