@@ -21,25 +21,18 @@
 // Own
 #include "EditProfileDialog.h"
 
-// Standard
-#include <cmath>
-
 // Qt
-#include <QBrush>
 #include <QDialog>
 #include <QDialogButtonBox>
 #include <QFileDialog>
 #include <QInputDialog>
 #include <QIcon>
-#include <QLinearGradient>
 #include <QPainter>
 #include <QPushButton>
-#include <QRadialGradient>
 #include <QStandardItem>
 #include <QTextCodec>
 #include <QTimer>
 #include <QUrl>
-#include <QVBoxLayout>
 #include <QStandardPaths>
 
 // KDE
@@ -65,7 +58,6 @@
 #include "ProfileManager.h"
 #include "ShellCommand.h"
 #include "WindowSystemInfo.h"
-#include "Shortcut_p.h"
 #include "FontDialog.h"
 
 using namespace Konsole;
@@ -515,7 +507,7 @@ void EditProfileDialog::showEnvironmentEditor()
     QString text = QInputDialog::getMultiLineText(this,
                                                   i18n("Edit Environment"),
                                                   i18n("One environment variable per line"),
-                                                  currentEnvironment.join(QStringLiteral("\n")),
+                                                  currentEnvironment.join(QLatin1Char('\n')),
                                                   &ok);
 
     QStringList newEnvironment;
@@ -962,7 +954,7 @@ bool EditProfileDialog::eventFilter(QObject *watched, QEvent *event)
 QSize EditProfileDialog::sizeHint() const
 {
     QFontMetrics fm(font());
-    const int ch = fm.width(QLatin1Char('0'));
+    const int ch = fm.boundingRect(QLatin1Char('0')).width();
 
     // By default minimum size is used. Increase it to make text inputs
     // on "tabs" page wider and to add some whitespace on right side
@@ -1059,7 +1051,7 @@ void EditProfileDialog::previewColorScheme(const QModelIndex &index)
 
 void EditProfileDialog::showFontDialog()
 {
-    if (!_fontDialog) {
+    if (_fontDialog == nullptr) {
         _fontDialog = new FontDialog(this);
         connect(_fontDialog, &FontDialog::fontChanged, this, [this](const QFont &font) {
             preview(Profile::Font, font);
@@ -1529,7 +1521,7 @@ void EditProfileDialog::setupButtonGroup(const ButtonGroupOptions &options, cons
 
     Q_ASSERT(options.buttons.count() > 0);
     auto *activeButton = options.group->button(currentValue);
-    if (!activeButton) {
+    if (activeButton == nullptr) {
         activeButton = options.buttons[0].button;
     }
     activeButton->setChecked(true);
@@ -1736,10 +1728,10 @@ int EditProfileDialog::maxSpinBoxWidth(const KPluralHandlingSpinBox *spinBox, co
     const QString singular  = suffix.subs(1).toString();
     const QString min       = QString::number(spinBox->minimum());
     const QString max       = QString::number(spinBox->maximum());
-    const int pluralWidth   = fm.width(plural);
-    const int singularWidth = fm.width(singular);
-    const int minWidth      = fm.width(min);
-    const int maxWidth      = fm.width(max);
+    const int pluralWidth   = fm.boundingRect(plural).width();
+    const int singularWidth = fm.boundingRect(singular).width();
+    const int minWidth      = fm.boundingRect(min).width();
+    const int maxWidth      = fm.boundingRect(max).width();
     const int width         = qMax(pluralWidth, singularWidth) + qMax(minWidth, maxWidth) + cursorWidth;
 
     // Based on QAbstractSpinBox::initStyleOption() from Qt
@@ -1905,7 +1897,7 @@ void ColorSchemeViewDelegate::paint(QPainter *painter, const QStyleOptionViewIte
     // Determine width of sample text using profile's font
     const QString sampleText = i18n("AaZz09...");
     QFontMetrics profileFontMetrics(profileFont);
-    const int sampleTextWidth = profileFontMetrics.width(sampleText);
+    const int sampleTextWidth = profileFontMetrics.boundingRect(sampleText).width();
 
     painter->drawText(option.rect.adjusted(sampleTextWidth + 15, 0, 0, 0),
                       Qt::AlignLeft | Qt::AlignVCenter,
