@@ -124,7 +124,7 @@ protected:
 class KONSOLEPRIVATE_EXPORT HistoryScrollFile : public HistoryScroll
 {
 public:
-    explicit HistoryScrollFile(const QString &logFileName);
+    explicit HistoryScrollFile();
     ~HistoryScrollFile() Q_DECL_OVERRIDE;
 
     int  getLines() Q_DECL_OVERRIDE;
@@ -384,15 +384,12 @@ public:
 class KONSOLEPRIVATE_EXPORT HistoryTypeFile : public HistoryType
 {
 public:
-    explicit HistoryTypeFile(const QString &fileName = QString());
+    explicit HistoryTypeFile();
 
     bool isEnabled() const Q_DECL_OVERRIDE;
     int maximumLineCount() const Q_DECL_OVERRIDE;
 
     HistoryScroll *scroll(HistoryScroll *) const Q_DECL_OVERRIDE;
-
-protected:
-    QString _fileName;
 };
 
 class KONSOLEPRIVATE_EXPORT CompactHistoryType : public HistoryType
