@@ -23,10 +23,10 @@
 #define KEYBOARDTRANSLATOR_H
 
 // Qt
-#include <QHash>
 #include <QList>
-#include <QString>
 #include <QMetaType>
+#include <QMultiHash>
+#include <QString>
 
 // Konsole
 #include "konsoleprivate_export.h"
@@ -207,12 +207,6 @@ public:
         /** See stateMask() */
         void setStateMask(States aStateMask);
 
-        /**
-         * Returns the key code and modifiers associated with this entry
-         * as a QKeySequence
-         */
-        //QKeySequence keySequence() const;
-
         /**
          * Returns this entry's conditions ( ie. its key code, modifier and state criteria )
          * as a string.
@@ -255,8 +249,6 @@ public:
     /** Constructs a new keyboard translator with the given @p name */
     explicit KeyboardTranslator(const QString &name);
 
-    //KeyboardTranslator(const KeyboardTranslator& other);
-
     /** Returns the name of this keyboard translator */
     QString name() const;
 
@@ -312,7 +304,7 @@ private:
 Q_DECLARE_OPERATORS_FOR_FLAGS(KeyboardTranslator::States)
 Q_DECLARE_OPERATORS_FOR_FLAGS(KeyboardTranslator::Commands)
 
-class FallbackKeyboardTranslator : public KeyboardTranslator
+class KONSOLEPRIVATE_EXPORT FallbackKeyboardTranslator : public KeyboardTranslator
 {
 public:
     FallbackKeyboardTranslator();
@@ -346,7 +338,7 @@ public:
  *  }
  * @endcode
  */
-class KeyboardTranslatorReader
+class KONSOLEPRIVATE_EXPORT KeyboardTranslatorReader
 {
 public:
     /** Constructs a new reader which parses the given @p source */
