@@ -21,7 +21,6 @@
 #include "MainWindow.h"
 
 // Qt
-#include <QVBoxLayout>
 #include <QMouseEvent>
 
 // KDE
@@ -30,8 +29,6 @@
 #include <KActionMenu>
 #include <KShortcutsDialog>
 #include <KLocalizedString>
-#include <KToggleAction>
-#include <KToggleFullScreenAction>
 #include <KWindowEffects>
 
 #include <QMenu>
@@ -42,7 +39,6 @@
 #include <KWindowSystem>
 #include <KXMLGUIFactory>
 #include <KNotifyConfigWidget>
-#include <KConfigDialog>
 #include <KIconLoader>
 
 // Konsole
@@ -496,13 +492,8 @@ Session *MainWindow::createSession(Profile::Ptr profile, const QString &director
         profile = ProfileManager::instance()->defaultProfile();
     }
 
-    Session *session = SessionManager::instance()->createSession(profile);
-
-    if (!directory.isEmpty() && profile->startInCurrentSessionDir()) {
-        session->setInitialWorkingDirectory(directory);
-    }
-
-    session->addEnvironmentEntry(QStringLiteral("KONSOLE_DBUS_WINDOW=/Windows/%1").arg(_viewManager->managerId()));
+    const QString newSessionDirectory = profile->startInCurrentSessionDir() ? directory : QString();
+    Session *session = _viewManager->createSession(profile, newSessionDirectory);
 
     // create view before starting the session process so that the session
     // doesn't suffer a change in terminal size right after the session
@@ -603,25 +594,46 @@ bool MainWindow::queryClose()
     int result;
 
     if (!processesRunning.isEmpty()) {
-        result = KMessageBox::warningYesNoCancelList(this,
-                                                     i18ncp("@info",
-                                                            "There is a process running in this window. "
-                                                            "Do you still want to quit?",
-                                                            "There are %1 processes running in this window. "
-                                                            "Do you still want to quit?",
-                                                            processesRunning.count()),
-                                                     processesRunning,
-                                                     i18nc("@title", "Confirm Close"),
-                                                     KGuiItem(i18nc("@action:button",
-                                                                    "Close &Window"),
-                                                              QStringLiteral("window-close")),
-                                                     KGuiItem(i18nc("@action:button",
-                                                                    "Close Current &Tab"),
-                                                              QStringLiteral("tab-close")),
-                                                     KStandardGuiItem::cancel(),
-                                                     // don't ask again name is wrong but I can't update.
-                                                     // this is not about tabs anymore. it's about empty tabs *or* splits.
-                                                     QStringLiteral("CloseAllTabs"));
+        if (openTabs == 1) {
+            result = KMessageBox::warningYesNoList(this,
+                                                         i18ncp("@info",
+                                                                "There is a process running in this window. "
+                                                                "Do you still want to quit?",
+                                                                "There are %1 processes running in this window. "
+                                                                "Do you still want to quit?",
+                                                                processesRunning.count()),
+                                                         processesRunning,
+                                                         i18nc("@title", "Confirm Close"),
+                                                         KGuiItem(i18nc("@action:button",
+                                                                        "Close &Window"),
+                                                                  QStringLiteral("window-close")),
+                                                         KStandardGuiItem::cancel(),
+                                                         // don't ask again name is wrong but I can't update.
+                                                         // this is not about tabs anymore. it's about empty tabs *or* splits.
+                                                         QStringLiteral("CloseAllTabs"));
+            if (result == KMessageBox::No) // No is equal to cancel closing
+                result = KMessageBox::Cancel;
+        } else {
+            result = KMessageBox::warningYesNoCancelList(this,
+                                                         i18ncp("@info",
+                                                                "There is a process running in this window. "
+                                                                "Do you still want to quit?",
+                                                                "There are %1 processes running in this window. "
+                                                                "Do you still want to quit?",
+                                                                processesRunning.count()),
+                                                         processesRunning,
+                                                         i18nc("@title", "Confirm Close"),
+                                                         KGuiItem(i18nc("@action:button",
+                                                                        "Close &Window"),
+                                                                  QStringLiteral("window-close")),
+                                                         KGuiItem(i18nc("@action:button",
+                                                                        "Close Current &Tab"),
+                                                                  QStringLiteral("tab-close")),
+                                                         KStandardGuiItem::cancel(),
+                                                         // don't ask again name is wrong but I can't update.
+                                                         // this is not about tabs anymore. it's about empty tabs *or* splits.
+                                                         QStringLiteral("CloseAllTabs"));
+        }
     } else {
         result = KMessageBox::warningYesNoCancel(this,
                                                  i18nc("@info",
@@ -732,7 +744,7 @@ void MainWindow::showManageProfilesDialog()
 void MainWindow::showSettingsDialog(const bool showProfilePage)
 {
     static ConfigurationDialog *confDialog = nullptr;
-    if (confDialog) {
+    if (confDialog != nullptr) {
         confDialog->show();
         return;
     }
@@ -746,7 +758,7 @@ void MainWindow::showSettingsDialog(const bool showProfilePage)
 
     const QString profilePageName = i18nc("@title Preferences page name", "Profiles");
     auto profilePage = new KPageWidgetItem(new ProfileSettings(confDialog), profilePageName);
-    profilePage->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
+    profilePage->setIcon(QIcon::fromTheme(QStringLiteral("preferences-system-profiles")));
     confDialog->addPage(profilePage, true);
 
     const QString tabBarPageName = i18nc("@title Preferences page name", "Tab Bar");
@@ -756,7 +768,7 @@ void MainWindow::showSettingsDialog(const bool showProfilePage)
 
     const QString temporaryFilesPageName = i18nc("@title Preferences page name", "Temporary Files");
     auto temporaryFilesPage = new KPageWidgetItem(new TemporaryFilesSettings(confDialog), temporaryFilesPageName);
-    temporaryFilesPage->setIcon(QIcon::fromTheme(QStringLiteral("inode-directory")));
+    temporaryFilesPage->setIcon(QIcon::fromTheme(QStringLiteral("folder-temp")));
     confDialog->addPage(temporaryFilesPage, true);
 
     if (showProfilePage) {
@@ -825,18 +837,26 @@ void MainWindow::setMenuBarInitialVisibility(bool visible)
 
 void MainWindow::setRemoveWindowTitleBarAndFrame(bool frameless)
 {
-    // This is used to check if the window is in "opening" state
-    // And avoid the visibility change when we change the window flag
-    bool oldVisibility = isVisible();
+    Qt::WindowFlags newFlags = frameless ? Qt::FramelessWindowHint : Qt::Window;
 
-    if (frameless) {
-        setWindowFlags(Qt::FramelessWindowHint);
-    } else {
-        setWindowFlags(Qt::Widget);
-    }
+    // The window is not yet visible
+    if (!isVisible()) {
+        setWindowFlags(newFlags);
 
-    if (oldVisibility && !isVisible()) {
+    // The window is visible and the setting changed
+    } else if (windowFlags().testFlag(Qt::FramelessWindowHint) != frameless) {
+        const auto oldGeometry = saveGeometry();
+        // This happens for every Konsole window. It depends on
+        // the fact that every window is processed in single thread
+        const auto oldActiveWindow = KWindowSystem::activeWindow();
+
+        setWindowFlags(newFlags);
+
+        // The setWindowFlags() has hidden the window. Show it again
+        // with previous geometry
+        restoreGeometry(oldGeometry);
         setVisible(true);
+        KWindowSystem::activateWindow(oldActiveWindow);
     }
 }
 
