@@ -21,7 +21,6 @@
 #define PART_H
 
 // KDE
-#include <KParts/Part>
 #include <KParts/ReadOnlyPart>
 #include <kde_terminal_interface.h>
 
@@ -30,9 +29,7 @@
 
 // Konsole
 #include "config-konsole.h"
-#include "Profile.h"
 
-class QAction;
 class QStringList;
 class QKeyEvent;
 
