@@ -43,7 +43,7 @@ void SearchHistoryTask::execute()
     }
 }
 
-void SearchHistoryTask::executeOnScreenWindow(const QPointer<Session> &session , ScreenWindowPtr window)
+void SearchHistoryTask::executeOnScreenWindow(const QPointer<Session> &session , const ScreenWindowPtr& window)
 {
     Q_ASSERT(session);
     Q_ASSERT(window);
@@ -165,7 +165,7 @@ void SearchHistoryTask::executeOnScreenWindow(const QPointer<Session> &session ,
 
     emit completed(false);
 }
-void SearchHistoryTask::highlightResult(ScreenWindowPtr window , int findPos)
+void SearchHistoryTask::highlightResult(const ScreenWindowPtr& window , int findPos)
 {
     //work out how many lines into the current block of text the search result was found
     //- looks a little painful, but it only has to be done once per search.
