@@ -35,7 +35,7 @@
 
 // Konsole
 #include "konsoleprivate_export.h"
-#include "config-konsole.h" //krazy:exclude=includes
+#include "config-konsole.h"
 #include "Shortcut_p.h"
 
 class QColor;
@@ -593,6 +593,11 @@ public Q_SLOTS:
      */
     Q_SCRIPTABLE void setProfile(const QString &profileName);
 
+    /**
+     * Returns the current session's profile name
+     */
+    Q_SCRIPTABLE QString profile();
+
 Q_SIGNALS:
 
     /** Emitted when the terminal process starts. */
