@@ -257,7 +257,7 @@ void SessionController::trackOutput(QKeyEvent* event)
 
     // Only jump to the bottom if the user actually typed something in,
     // not if the user e. g. just pressed a modifier.
-    if (event->text().isEmpty() && (event->modifiers() || shouldNotTriggerScroll)) {
+    if (event->text().isEmpty() && ((event->modifiers() != 0u) || shouldNotTriggerScroll)) {
         return;
     }
 
@@ -885,6 +885,7 @@ void SessionController::renameSession()
     }
 }
 
+// This is called upon Menu->Close Sesssion and right-click on tab->Close Tab
 bool SessionController::confirmClose() const
 {
     if (_session->isForegroundProcessActive()) {
@@ -907,7 +908,12 @@ bool SessionController::confirmClose() const
                             "  Are you sure you want to close it?", title);
         }
 
-        int result = KMessageBox::warningYesNo(_view->window(), question, i18n("Confirm Close"));
+        int result = KMessageBox::warningYesNo(_view->window(),
+                                               question,
+                                               i18n("Confirm Close"),
+                                               KStandardGuiItem::yes(),
+                                               KStandardGuiItem::no(),
+                                               QStringLiteral("CloseSingleTab"));
         return result == KMessageBox::Yes;
     }
     return true;
@@ -1546,7 +1552,7 @@ void SessionController::updateSessionIcon()
 {
     // If the default profile icon is being used, don't put it on the tab
     // Only show the icon if the user specifically chose one
-    if (_session->iconName() == QStringLiteral("utilities-terminal")) {
+    if (_session->iconName() == QLatin1String("utilities-terminal")) {
         _sessionIconName = QString();
     } else {
         _sessionIconName = _session->iconName();
