@@ -35,10 +35,6 @@
 #include "Profile.h"
 #include "Enumeration.h"
 
-namespace KIO {
-class Job;
-}
-
 class QAction;
 class QTextCodec;
 class QKeyEvent;
@@ -46,7 +42,6 @@ class QTimer;
 class QUrl;
 
 class KCodecAction;
-class KJob;
 class QAction;
 class KActionMenu;
 
