@@ -36,7 +36,8 @@ const TabTitleFormatButton::Element TabTitleFormatButton::_localElements[] = {
     { QStringLiteral("%w"), I18N_NOOP("Window Title Set by Shell: %w") },
     { QStringLiteral("%#"), I18N_NOOP("Session Number: %#") },
     { QStringLiteral("%u"), I18N_NOOP("User Name: %u") },
-    { QStringLiteral("%h"), I18N_NOOP("Local Host: %h") }
+    { QStringLiteral("%h"), I18N_NOOP("Local Host: %h") },
+    { QStringLiteral("%B"), I18N_NOOP("User's Bourne prompt sigil: %B") } //  ($, or # for superuser)
 };
 const int TabTitleFormatButton::_localElementCount
     = sizeof(_localElements) / sizeof(TabTitleFormatButton::Element);
