@@ -20,14 +20,13 @@
 // Own
 #include "ViewManager.h"
 
-#include <config-konsole.h>
+#include "config-konsole.h"
 
 // Qt
 #include <QStringList>
 #include <QTabBar>
 
 // KDE
-#include <KAcceleratorManager>
 #include <KLocalizedString>
 #include <KActionCollection>
 #include <KConfigGroup>
@@ -266,7 +265,7 @@ void ViewManager::toggleActionsBasedOnState() {
         tabOnlyAction->setEnabled(count > 1);
     }
 
-    if (_viewContainer && _viewContainer->activeViewSplitter()) {
+    if ((_viewContainer != nullptr) && (_viewContainer->activeViewSplitter() != nullptr)) {
         const int splitCount = _viewContainer
                 ->activeViewSplitter()
                 ->getToplevelSplitter()
@@ -444,6 +443,17 @@ Session* ViewManager::forgetTerminal(TerminalDisplay* terminal)
     return session;
 }
 
+Session* ViewManager::createSession(const Profile::Ptr &profile, const QString &directory)
+{
+    Session *session = SessionManager::instance()->createSession(profile);
+    Q_ASSERT(session);
+    if (!directory.isEmpty()) {
+        session->setInitialWorkingDirectory(directory);
+    }
+    session->addEnvironmentEntry(QStringLiteral("KONSOLE_DBUS_WINDOW=/Windows/%1").arg(managerId()));
+    return session;
+}
+
 void ViewManager::sessionFinished()
 {
     // if this slot is called after the view manager's main widget
@@ -464,7 +474,7 @@ void ViewManager::sessionFinished()
 
     // Before deleting the view, let's unmaximize if it's maximized.
     auto *splitter = qobject_cast<ViewSplitter*>(view->parentWidget());
-    if (!splitter) {
+    if (splitter == nullptr) {
         return;
     }
 
@@ -483,7 +493,7 @@ void ViewManager::sessionFinished()
         emit unplugController(_pluggedController);
     }
 
-    if (_sessionMap.size() > 0) {
+    if (!_sessionMap.empty()) {
         updateTerminalDisplayHistory(view, true);
         focusAnotherTerminal(toplevelSplitter);
         toggleActionsBasedOnState();
@@ -535,15 +545,19 @@ void ViewManager::splitTopBottom()
 
 void ViewManager::splitView(Qt::Orientation orientation)
 {
-    auto viewSplitter = qobject_cast<ViewSplitter*>(_viewContainer->currentWidget());
+    int currentSessionId = currentSession();
+    // At least one display/session exists if we are splitting
+    Q_ASSERT(currentSessionId >= 0);
 
-    // get the currently applied profile and use it to create the new tab.
-    auto *currentDisplay = viewSplitter->findChild<TerminalDisplay*>();
-    auto profile = SessionManager::instance()->sessionProfile(_sessionMap[currentDisplay]);
+    Session *activeSession = SessionManager::instance()->idToSession(currentSessionId);
+    Q_ASSERT(activeSession);
 
-    // Create a new session with the selected profile.
-    auto *session = SessionManager::instance()->createSession(profile);
-    session->addEnvironmentEntry(QStringLiteral("KONSOLE_DBUS_WINDOW=/Windows/%1").arg(managerId()));
+    auto profile = SessionManager::instance()->sessionProfile(activeSession);
+
+    const QString directory = profile->startInCurrentSessionDir()
+                              ? activeSession->currentWorkingDirectory()
+                              : QString();
+    auto *session = createSession(profile, directory);
 
     auto terminalDisplay = createView(session);
 
@@ -604,6 +618,7 @@ void ViewManager::controllerChanged(SessionController *controller)
         return;
     }
 
+    _viewContainer->setFocusProxy(controller->view());
     updateTerminalDisplayHistory(controller->view());
 
     _pluggedController = controller;
@@ -774,9 +789,10 @@ void ViewManager::viewDestroyed(QWidget *view)
 TerminalDisplay *ViewManager::createTerminalDisplay(Session *session)
 {
     auto display = new TerminalDisplay(nullptr);
-    display->setRandomSeed(session->sessionId() * 31);
+    display->setRandomSeed(session->sessionId() | (qApp->applicationPid() << 10));
     connect(display, &TerminalDisplay::requestToggleExpansion,
             _viewContainer, &TabbedViewContainer::toggleMaximizeCurrentTerminal);
+
     return display;
 }
 
@@ -876,7 +892,7 @@ QJsonObject saveSessionsRecurse(QSplitter *splitter) {
 
         if (maybeSplitter != nullptr) {
             internalWidgets.append(saveSessionsRecurse(maybeSplitter));
-        } else if (maybeTerminalDisplay) {
+        } else if (maybeTerminalDisplay != nullptr) {
             internalWidgets.append(saveSessionTerminal(maybeTerminalDisplay));
         }
     }
@@ -890,7 +906,7 @@ void ViewManager::saveSessions(KConfigGroup &group)
 {
     QJsonArray rootArray;
     for(int i = 0; i < _viewContainer->count(); i++) {
-        QSplitter *splitter = qobject_cast<QSplitter*>(_viewContainer->widget(i));
+        auto *splitter = qobject_cast<QSplitter*>(_viewContainer->widget(i));
         rootArray.append(saveSessionsRecurse(splitter));
     }
 
@@ -903,7 +919,7 @@ namespace {
 ViewSplitter *restoreSessionsSplitterRecurse(const QJsonObject& jsonSplitter, ViewManager *manager)
 {
     auto splitterWidgets = jsonSplitter[QStringLiteral("Widgets")].toArray();
-    auto orientation = (jsonSplitter[QStringLiteral("Orientation")].toString() == QStringLiteral("Horizontal"))
+    auto orientation = (jsonSplitter[QStringLiteral("Orientation")].toString() == QLatin1String("Horizontal"))
         ? Qt::Horizontal : Qt::Vertical;
 
     auto *currentSplitter = new ViewSplitter();
@@ -1002,79 +1018,51 @@ QStringList ViewManager::sessionList()
 
 int ViewManager::currentSession()
 {
-    QHash<TerminalDisplay *, Session *>::const_iterator i;
-    for (i = _sessionMap.constBegin(); i != _sessionMap.constEnd(); ++i) {
-        if (i.key()->isVisible()) {
-            return i.value()->sessionId();
-        }
+    if (_pluggedController) {
+        Q_ASSERT(_pluggedController->session() != nullptr);
+        return _pluggedController->session()->sessionId();
     }
     return -1;
 }
 
 void ViewManager::setCurrentSession(int sessionId)
 {
-    QHash<TerminalDisplay *, Session *>::const_iterator i;
-    for (i = _sessionMap.constBegin(); i != _sessionMap.constEnd(); ++i) {
-        if (i.value()->sessionId() == sessionId) {
-            i.key()->setFocus(Qt::OtherFocusReason);
-            return;
-        }
+    auto *session = SessionManager::instance()->idToSession(sessionId);
+    if (session == nullptr || session->views().count() == 0) {
+        return;
+    }
+
+    auto *display = session->views().at(0);
+    if (display != nullptr) {
+        display->setFocus(Qt::OtherFocusReason);
     }
 }
 
 int ViewManager::newSession()
 {
-    Profile::Ptr profile = ProfileManager::instance()->defaultProfile();
-    Session *session = SessionManager::instance()->createSession(profile);
-
-    session->addEnvironmentEntry(QStringLiteral("KONSOLE_DBUS_WINDOW=/Windows/%1").arg(managerId()));
-
-    auto newView = createView(session);
-    activeContainer()->addView(newView);
-    session->run();
-
-    return session->sessionId();
+    return newSession(QString(), QString());
 }
 
 int ViewManager::newSession(const QString &profile)
 {
-    const QList<Profile::Ptr> profilelist = ProfileManager::instance()->allProfiles();
-    Profile::Ptr profileptr = ProfileManager::instance()->defaultProfile();
-
-    for (const auto &i : profilelist) {
-        if (i->name() == profile) {
-            profileptr = i;
-            break;
-        }
-    }
-
-    Session *session = SessionManager::instance()->createSession(profileptr);
-
-    session->addEnvironmentEntry(QStringLiteral("KONSOLE_DBUS_WINDOW=/Windows/%1").arg(managerId()));
-
-    auto newView = createView(session);
-    activeContainer()->addView(newView);
-    session->run();
-
-    return session->sessionId();
+    return newSession(profile, QString());
 }
 
 int ViewManager::newSession(const QString &profile, const QString &directory)
 {
-    const QList<Profile::Ptr> profilelist = ProfileManager::instance()->allProfiles();
     Profile::Ptr profileptr = ProfileManager::instance()->defaultProfile();
+    if(!profile.isEmpty()) {
+        const QList<Profile::Ptr> profilelist = ProfileManager::instance()->allProfiles();
 
-    for (const auto &i : profilelist) {
-        if (i->name() == profile) {
-            profileptr = i;
-            break;
+        for (const auto &i : profilelist) {
+            if (i->name() == profile) {
+                profileptr = i;
+                break;
+            }
         }
     }
 
-    Session *session = SessionManager::instance()->createSession(profileptr);
-    session->setInitialWorkingDirectory(directory);
-
-    session->addEnvironmentEntry(QStringLiteral("KONSOLE_DBUS_WINDOW=/Windows/%1").arg(managerId()));
+    Session *session = createSession(profileptr, directory);
 
     auto newView = createView(session);
     activeContainer()->addView(newView);
