@@ -196,6 +196,15 @@ public:
 
     QHash<TerminalDisplay*, Session*> forgetAll(ViewSplitter* splitter);
     Session* forgetTerminal(TerminalDisplay* terminal);
+
+    /**
+     * Creates and returns new session
+     *
+     * The session has specified @p profile, working @p directory
+     * and configured environment.
+     */
+    Session* createSession(const Profile::Ptr &profile, const QString &directory = QString());
+
 Q_SIGNALS:
     /** Emitted when the last view is removed from the view manager */
     void empty();
@@ -253,6 +262,11 @@ public Q_SLOTS:
     /** DBus slot that sets the current (active) session window */
     Q_SCRIPTABLE void setCurrentSession(int sessionId);
 
+    /** DBus slot that creates a new session in the current view with the associated
+      * default profile and the default working directory
+      */
+    Q_SCRIPTABLE int newSession();
+
     /** DBus slot that creates a new session in the current view.
      * @param profile the name of the profile to be used
      * started.
@@ -274,11 +288,6 @@ public Q_SLOTS:
     // DBus slot that returns a string list of defined (known) profiles
     Q_SCRIPTABLE QStringList profileList();
 
-    /** DBus slot that creates a new session in the current view with the associated
-      * default profile and the default working directory
-      */
-    Q_SCRIPTABLE int newSession();
-
     /** DBus slot that changes the view port to the next session */
     Q_SCRIPTABLE void nextSession();
 
