@@ -23,13 +23,10 @@
 #include "ViewSplitter.h"
 
 // Qt
-#include <QDebug>
 #include <QChildEvent>
-#include <QScrollBar>
 #include <QDragEnterEvent>
 #include <QDropEvent>
 #include <QDragMoveEvent>
-#include <QMimeType>
 #include <QMimeData>
 #include <QApplication>
 #include <memory>
@@ -63,7 +60,7 @@ void ViewSplitter::adjustActiveTerminalDisplaySize(int percentage)
     QList<int> containerSizes = parentSplitter->sizes();
 
     const int oldSize = containerSizes[containerIndex];
-    const int newSize = static_cast<int>(oldSize * (1.0 + percentage / 100.0));
+    const auto newSize = static_cast<int>(oldSize * (1.0 + percentage / 100.0));
     const int perContainerDelta = (count() == 1) ? 0 : ((newSize - oldSize) / (count() - 1)) * (-1);
 
     for (int& size : containerSizes) {
@@ -99,7 +96,7 @@ void ViewSplitter::updateSizes()
 void ViewSplitter::addTerminalDisplay(TerminalDisplay *terminalDisplay, Qt::Orientation containerOrientation, AddBehavior behavior)
 {
     ViewSplitter *splitter = activeSplitter();
-    const int currentIndex = !splitter->activeTerminalDisplay() ? splitter->count()
+    const int currentIndex = splitter->activeTerminalDisplay() == nullptr ? splitter->count()
                             : splitter->indexOf(splitter->activeTerminalDisplay());
 
     if (splitter->count() < 2) {
@@ -129,7 +126,7 @@ void ViewSplitter::childEvent(QChildEvent *event)
         if (count() == 0) {
             deleteLater();
         }
-        if (!findChild<TerminalDisplay*>()) {
+        if (findChild<TerminalDisplay*>() == nullptr) {
             deleteLater();
         }
     }
@@ -169,13 +166,12 @@ void ViewSplitter::handleFocusDirection(Qt::Orientation orientation, int directi
     auto child = topSplitter->childAt(newPoint);
 
     TerminalDisplay *focusTerminal = nullptr;
-    if (TerminalDisplay* terminal = qobject_cast<TerminalDisplay*>(child)) {
+    if (auto* terminal = qobject_cast<TerminalDisplay*>(child)) {
         focusTerminal = terminal;
-    } else if (qobject_cast<QSplitterHandle*>(child)) {
+    } else if (qobject_cast<QSplitterHandle*>(child) != nullptr) {
         auto targetSplitter = qobject_cast<QSplitter*>(child->parent());
         focusTerminal = qobject_cast<TerminalDisplay*>(targetSplitter->widget(0));
-    } else if (qobject_cast<QWidget*>(child)) {
-        TerminalDisplay *terminalParent = nullptr;
+    } else if (qobject_cast<QWidget*>(child) != nullptr) {
         while(child != nullptr && focusTerminal == nullptr) {
             focusTerminal = qobject_cast<TerminalDisplay*>(child->parentWidget());
             child = child->parentWidget();
@@ -209,7 +205,7 @@ void ViewSplitter::focusRight()
 TerminalDisplay *ViewSplitter::activeTerminalDisplay() const
 {
     auto focusedWidget = qobject_cast<TerminalDisplay*>(focusWidget());
-    return focusedWidget ? focusedWidget : findChild<TerminalDisplay*>();
+    return focusedWidget != nullptr ? focusedWidget : findChild<TerminalDisplay*>();
 }
 
 void ViewSplitter::toggleMaximizeCurrentTerminal()
@@ -277,7 +273,7 @@ void ViewSplitter::handleMinimizeMaximize(bool maximize)
 ViewSplitter *ViewSplitter::getToplevelSplitter()
 {
     ViewSplitter *current = this;
-    while(qobject_cast<ViewSplitter*>(current->parentWidget())) {
+    while(qobject_cast<ViewSplitter*>(current->parentWidget()) != nullptr) {
         current = qobject_cast<ViewSplitter*>(current->parentWidget());
     }
     return current;
@@ -293,8 +289,9 @@ void Konsole::ViewSplitter::dragEnterEvent(QDragEnterEvent* ev)
     if (ev->mimeData()->hasFormat(dragId)) {
         auto other_pid = ev->mimeData()->data(dragId).toInt();
         // don't accept the drop if it's another instance of konsole
-        if (qApp->applicationPid() != other_pid)
+        if (qApp->applicationPid() != other_pid) {
             return;
+        }
         if (getToplevelSplitter()->terminalMaximized()) {
             return;
         }
@@ -306,21 +303,22 @@ void Konsole::ViewSplitter::dragMoveEvent(QDragMoveEvent* ev)
 {
     auto currentWidget = childAt(ev->pos());
     if (auto terminal = qobject_cast<TerminalDisplay*>(currentWidget)) {
-        if (currentDragTarget && currentDragTarget != terminal) {
+        if ((currentDragTarget != nullptr) && currentDragTarget != terminal) {
             currentDragTarget->hideDragTarget();
         }
         if (terminal == ev->source()) {
             return;
         }
         currentDragTarget = terminal;
-        currentDragTarget->showDragTarget();
+        auto localPos = currentDragTarget->mapFromParent(ev->pos());
+        currentDragTarget->showDragTarget(localPos);
     }
 }
 
 void Konsole::ViewSplitter::dragLeaveEvent(QDragLeaveEvent* event)
 {
     Q_UNUSED(event);
-    if (currentDragTarget) {
+    if (currentDragTarget != nullptr) {
         currentDragTarget->hideDragTarget();
         currentDragTarget = nullptr;
     }
@@ -332,7 +330,7 @@ void Konsole::ViewSplitter::dropEvent(QDropEvent* ev)
         if (getToplevelSplitter()->terminalMaximized()) {
             return;
         }
-        if (currentDragTarget) {
+        if (currentDragTarget != nullptr) {
             currentDragTarget->hideDragTarget();
             auto source = qobject_cast<TerminalDisplay*>(ev->source());
             source->setVisible(false);
