@@ -33,6 +33,8 @@ class KeyboardTranslatorTest : public QObject
 private Q_SLOTS:
     void testEntryTextWildcards();
     void testEntryTextWildcards_data();
+    void testFallback();
+    void testHexKeys();
 };
 
 }
