@@ -33,7 +33,7 @@ class TerminalCharacterDecoderTest : public QObject
     Q_OBJECT
 
 private Q_SLOTS:
-    Character* convertToCharacter(QString text, QVector<RenditionFlags> renditions);
+    Character* convertToCharacter(const QString &text, QVector<RenditionFlags> renditions);
     void testPlainTextDecoder();
     void testPlainTextDecoder_data();
     void testHTMLDecoder();
