@@ -26,7 +26,6 @@
 // Qt
 #include <QDir>
 #include <QSignalSpy>
-#include <QTimer>
 
 // KDE
 #include <KService>
@@ -58,7 +57,7 @@ void TerminalInterfaceTest::initTestCase()
     auto buildPath = libraryPaths.last();
     QCoreApplication::removeLibraryPath(buildPath);
     // konsolepart.so is in ../autotests/
-    if (buildPath.endsWith(QStringLiteral("/autotests"))) {
+    if (buildPath.endsWith(QLatin1String("/autotests"))) {
         buildPath.chop(10);
     }
     QCoreApplication::addLibraryPath(buildPath);
