@@ -26,7 +26,6 @@
 #define CONFIGURATIONDIALOG_H
 
 // Qt
-#include <QWidget>
 #include <QButtonGroup>
 #include <QAbstractButton>
 #include <QTimer>
@@ -35,13 +34,11 @@
 // KDE
 #include <KPageDialog>
 #include <KCoreConfigSkeleton>
-#include <QDebug>
 
 // Konsole
 #include "konsoleprivate_export.h"
 
-class KConfig;
-class KCoreConfigSkeleton;
+class QWidget;
 class KConfigDialogManager;
 
 namespace Konsole {
@@ -103,14 +100,10 @@ public:
 
     void addChildren(const QObject *parentObj)
     {
-        for (const QObject *child: parentObj->children()) {
-            if (!child->objectName().startsWith(ManagedNamePrefix)) {
-                continue;
-            }
-
-            const char *className = child->metaObject()->className();
-            if (qstrcmp(className, "QButtonGroup") == 0) {
-                add(qobject_cast<const QButtonGroup *>(child));
+        const auto allButtonGroups = parentObj->findChildren<QButtonGroup *>();
+        for (const auto *buttonGroup: allButtonGroups) {
+            if (buttonGroup->objectName().startsWith(ManagedNamePrefix)) {
+                add(buttonGroup);
             }
         }
     }
@@ -154,7 +147,7 @@ public Q_SLOTS:
         blockSignals(true);
         for(const QButtonGroup *group: qAsConst(_groups)) {
             auto *enumItem = groupToConfigItemEnum(group);
-            if(!enumItem) {
+            if(enumItem == nullptr) {
                 continue;
             }
 
@@ -167,7 +160,7 @@ public Q_SLOTS:
                     break;
                 }
             }
-            if(!currentButton) {
+            if(currentButton == nullptr) {
                 return;
             }
             currentButton->setChecked(true);
@@ -189,11 +182,11 @@ public Q_SLOTS:
         bool updateConfig = false;
         for(const QButtonGroup *group: qAsConst(_groups)) {
             auto *enumItem = groupToConfigItemEnum(group);
-            if(!enumItem) {
+            if(enumItem == nullptr) {
                 continue;
             }
             const auto *currentButton = group->checkedButton();
-            if(!currentButton) {
+            if(currentButton == nullptr) {
                 continue;
             }
             const int value = buttonToEnumValue(currentButton);
@@ -222,7 +215,7 @@ protected Q_SLOTS:
             return;
         }
         auto *enumItem = groupToConfigItemEnum(button->group());
-        if(!enumItem) {
+        if(enumItem == nullptr) {
             return;
         }
 
@@ -240,11 +233,11 @@ private:
         Q_ASSERT(group);
         const QString key = group->objectName().mid(ManagedNamePrefix.length());
         auto *item = _config->findItem(key);
-        if(!item) {
+        if(item == nullptr) {
             return nullptr;
         }
         auto *enumItem = dynamic_cast<KCoreConfigSkeleton::ItemEnum *>(item);
-        if(!enumItem) {
+        if(enumItem == nullptr) {
             return nullptr;
         }
         return enumItem;
@@ -260,7 +253,7 @@ private:
         }
 
         const auto *enumItem = groupToConfigItemEnum(button->group());
-        if(!enumItem) {
+        if(enumItem == nullptr) {
             return -1;
         }
         const auto &choices = enumItem->choices();
