@@ -19,7 +19,6 @@
 
 // Own
 #include "ProfileSettings.h"
-#include <QPainter>
 
 // Qt
 #include <QFileInfo>
@@ -27,11 +26,6 @@
 #include <QStandardItem>
 #include <QKeyEvent>
 
-// KDE
-#include <KLocalizedString>
-#include <KIconLoader>
-#include <QPushButton>
-
 // Konsole
 #include "EditProfileDialog.h"
 #include "ProfileManager.h"
@@ -509,10 +503,10 @@ QSize Konsole::ShortcutItemDelegate::sizeHint(const QStyleOptionViewItem &option
     QFontMetrics fm = option.fontMetrics;
 
     static const int editorMargins = 16; // chosen empirically
-    const int width = fm.width(shortcutString + QStringLiteral(", ..."))
+    const int width = fm.boundingRect(shortcutString + QStringLiteral(", ...")).width()
                       + editorMargins;
 
-    return QSize(width, QStyledItemDelegate::sizeHint(option, index).height());
+    return {width, QStyledItemDelegate::sizeHint(option, index).height()};
 }
 
 void Konsole::ShortcutItemDelegate::destroyEditor(QWidget *editor, const QModelIndex &index) const
